import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeExternalVpnGatewayConfig extends TerraformMetaArguments {
    /**
     * An optional description of this resource.
     */
    readonly description?: string;
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035.  Specifically, the name must be 1-63 characters long and
     * match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
     * the first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     */
    readonly name: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * Indicates the redundancy type of this external VPN gateway Possible values: ["FOUR_IPS_REDUNDANCY", "SINGLE_IP_INTERNALLY_REDUNDANT", "TWO_IPS_REDUNDANCY"].
     */
    readonly redundancyType?: string;
    /**
     * interface block.
     */
    readonly interface?: ComputeExternalVpnGatewayInterface[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeExternalVpnGatewayTimeouts;
}
/**
 *
 */
export interface ComputeExternalVpnGatewayInterface {
    /**
     * The numberic ID for this interface.
     *
     * Allowed values are based on the redundancy type
     * of this external VPN gateway
     * '0 - SINGLE_IP_INTERNALLY_REDUNDANT'
     * '0, 1 - TWO_IPS_REDUNDANCY'
     * '0, 1, 2, 3 - FOUR_IPS_REDUNDANCY'
     */
    readonly id?: number;
    /**
     * IP address of the interface in the external VPN gateway.
     *
     * Only IPv4 is supported. This IP address can be either from
     * your on-premise gateway or another Cloud provider's VPN gateway,
     * it cannot be an IP address from Google Compute Engine.
     */
    readonly ipAddress?: string;
}
/**
 *
 */
export interface ComputeExternalVpnGatewayTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class ComputeExternalVpnGateway extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeExternalVpnGatewayConfig);
    private _description?;
    /**
     *
     */
    get description(): string | undefined;
    /**
     *
     */
    set description(value: string | undefined);
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    private _project?;
    /**
     *
     */
    get project(): string | undefined;
    /**
     *
     */
    set project(value: string | undefined);
    private _redundancyType?;
    /**
     *
     */
    get redundancyType(): string | undefined;
    /**
     *
     */
    set redundancyType(value: string | undefined);
    /**
     *
     */
    get selfLink(): string;
    private _interface?;
    /**
     *
     */
    get interface(): ComputeExternalVpnGatewayInterface[] | undefined;
    /**
     *
     */
    set interface(value: ComputeExternalVpnGatewayInterface[] | undefined);
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeExternalVpnGatewayTimeouts | undefined;
    /**
     *
     */
    set timeouts(value: ComputeExternalVpnGatewayTimeouts | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
