import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface ComputeVpnTunnelConfig extends TerraformMetaArguments {
    /**
     * An optional description of this resource.
     */
    readonly description?: string;
    /**
     * IKE protocol version to use when establishing the VPN tunnel with peer VPN gateway.
     *
     * Acceptable IKE versions are 1 or 2. Default version is 2.
     */
    readonly ikeVersion?: number;
    /**
     * Local traffic selector to use when establishing the VPN tunnel with peer VPN gateway.
     *
     * The value should be a CIDR formatted string,
     * for example '192.168.0.0/16'. The ranges should be disjoint.
     * Only IPv4 is supported.
     */
    readonly localTrafficSelector?: string[];
    /**
     * Name of the resource.
     *
     * The name must be 1-63 characters long, and
     * comply with RFC1035. Specifically, the name must be 1-63
     * characters long and match the regular expression
     * '[a-z]([-a-z0-9]*[a-z0-9])?' which means the first character
     * must be a lowercase letter, and all following characters must
     * be a dash, lowercase letter, or digit,
     * except the last character, which cannot be a dash.
     */
    readonly name: string;
    /**
     * URL of the peer side external VPN gateway to which this VPN tunnel is connected.
     */
    readonly peerExternalGateway?: string;
    /**
     * The interface ID of the external VPN gateway to which this VPN tunnel is connected.
     */
    readonly peerExternalGatewayInterface?: number;
    /**
     * URL of the peer side HA GCP VPN gateway to which this VPN tunnel is connected.
     *
     * If provided, the VPN tunnel will automatically use the same vpn_gateway_interface
     * ID in the peer GCP VPN gateway.
     * This field must reference a 'google_compute_ha_vpn_gateway' resource.
     */
    readonly peerGcpGateway?: string;
    /**
     * IP address of the peer VPN gateway.
     *
     * Only IPv4 is supported.
     */
    readonly peerIp?: string;
    /**
     *
     */
    readonly project?: string;
    /**
     * The region where the tunnel is located.
     *
     * If unset, is set to the region of 'target_vpn_gateway'.
     */
    readonly region?: string;
    /**
     * Remote traffic selector to use when establishing the VPN tunnel with peer VPN gateway.
     *
     * The value should be a CIDR formatted string,
     * for example '192.168.0.0/16'. The ranges should be disjoint.
     * Only IPv4 is supported.
     */
    readonly remoteTrafficSelector?: string[];
    /**
     * URL of router resource to be used for dynamic routing.
     */
    readonly router?: string;
    /**
     * Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway.
     */
    readonly sharedSecret: string;
    /**
     * URL of the Target VPN gateway with which this VPN tunnel is associated.
     */
    readonly targetVpnGateway?: string;
    /**
     * URL of the VPN gateway with which this VPN tunnel is associated.
     *
     * This must be used if a High Availability VPN gateway resource is created.
     * This field must reference a 'google_compute_ha_vpn_gateway' resource.
     */
    readonly vpnGateway?: string;
    /**
     * The interface ID of the VPN gateway with which this VPN tunnel is associated.
     */
    readonly vpnGatewayInterface?: number;
    /**
     * timeouts block.
     */
    readonly timeouts?: ComputeVpnTunnelTimeouts;
}
/**
 *
 */
export interface ComputeVpnTunnelTimeouts {
    /**
     *
     */
    readonly create?: string;
    /**
     *
     */
    readonly delete?: string;
}
/**
 *
 */
export declare class ComputeVpnTunnel extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: ComputeVpnTunnelConfig);
    /**
     *
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     *
     */
    get description(): string | undefined;
    /**
     *
     */
    set description(value: string | undefined);
    /**
     *
     */
    get detailedStatus(): string;
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    private _ikeVersion?;
    /**
     *
     */
    get ikeVersion(): number | undefined;
    /**
     *
     */
    set ikeVersion(value: number | undefined);
    private _localTrafficSelector?;
    /**
     *
     */
    get localTrafficSelector(): string[] | undefined;
    /**
     *
     */
    set localTrafficSelector(value: string[] | undefined);
    private _name;
    /**
     *
     */
    get name(): string;
    /**
     *
     */
    set name(value: string);
    private _peerExternalGateway?;
    /**
     *
     */
    get peerExternalGateway(): string | undefined;
    /**
     *
     */
    set peerExternalGateway(value: string | undefined);
    private _peerExternalGatewayInterface?;
    /**
     *
     */
    get peerExternalGatewayInterface(): number | undefined;
    /**
     *
     */
    set peerExternalGatewayInterface(value: number | undefined);
    private _peerGcpGateway?;
    /**
     *
     */
    get peerGcpGateway(): string | undefined;
    /**
     *
     */
    set peerGcpGateway(value: string | undefined);
    private _peerIp?;
    /**
     *
     */
    get peerIp(): string | undefined;
    /**
     *
     */
    set peerIp(value: string | undefined);
    private _project?;
    /**
     *
     */
    get project(): string | undefined;
    /**
     *
     */
    set project(value: string | undefined);
    private _region?;
    /**
     *
     */
    get region(): string | undefined;
    /**
     *
     */
    set region(value: string | undefined);
    private _remoteTrafficSelector?;
    /**
     *
     */
    get remoteTrafficSelector(): string[] | undefined;
    /**
     *
     */
    set remoteTrafficSelector(value: string[] | undefined);
    private _router?;
    /**
     *
     */
    get router(): string | undefined;
    /**
     *
     */
    set router(value: string | undefined);
    /**
     *
     */
    get selfLink(): string;
    private _sharedSecret;
    /**
     *
     */
    get sharedSecret(): string;
    /**
     *
     */
    set sharedSecret(value: string);
    /**
     *
     */
    get sharedSecretHash(): string;
    private _targetVpnGateway?;
    /**
     *
     */
    get targetVpnGateway(): string | undefined;
    /**
     *
     */
    set targetVpnGateway(value: string | undefined);
    /**
     *
     */
    get tunnelId(): string;
    private _vpnGateway?;
    /**
     *
     */
    get vpnGateway(): string | undefined;
    /**
     *
     */
    set vpnGateway(value: string | undefined);
    private _vpnGatewayInterface?;
    /**
     *
     */
    get vpnGatewayInterface(): number | undefined;
    /**
     *
     */
    set vpnGatewayInterface(value: number | undefined);
    private _timeouts?;
    /**
     *
     */
    get timeouts(): ComputeVpnTunnelTimeouts | undefined;
    /**
     *
     */
    set timeouts(value: ComputeVpnTunnelTimeouts | undefined);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
